@@ -9,11 +9,6 @@ import random
 from vocode.streaming.agent.bot_sentiment_analyser import (
     BotSentimentAnalyser,
 )
-from vocode.streaming.factory import (
-    create_agent,
-    create_synthesizer,
-    create_transcriber,
-)
 from vocode.streaming.models.message import BaseMessage
 from vocode.streaming.output_device.base_output_device import BaseOutputDevice
 from vocode.streaming.utils.goodbye_model import GoodbyeModel
@@ -24,7 +19,7 @@ from vocode.streaming.models.agent import (
     FILLER_AUDIO_DEFAULT_SILENCE_THRESHOLD_SECONDS,
 )
 from vocode.streaming.models.synthesizer import (
-    TrackBotSentimentConfig,
+    SentimentConfig,
 )
 from vocode.streaming.constants import (
     TEXT_TO_SPEECH_CHUNK_SIZE_SECONDS,
@@ -76,18 +71,14 @@ class StreamingConversation:
         self.per_chunk_allowance_seconds = per_chunk_allowance_seconds
         self.transcript = Transcript()
         self.bot_sentiment = None
-        if self.synthesizer.get_synthesizer_config().track_bot_sentiment_in_voice:
-            if isinstance(
-                self.synthesizer.get_synthesizer_config().track_bot_sentiment_in_voice,
-                bool,
-            ):
-                self.track_bot_sentiment_config = TrackBotSentimentConfig()
-            else:
-                self.track_bot_sentiment_config = (
-                    self.synthesizer.get_synthesizer_config().track_bot_sentiment_in_voice
-                )
+        if self.agent.get_agent_config().track_bot_sentiment:
+            self.sentiment_config = (
+                self.synthesizer.get_synthesizer_config().sentiment_config
+            )
+            if not self.sentiment_config:
+                self.sentiment_config = SentimentConfig()
             self.bot_sentiment_analyser = BotSentimentAnalyser(
-                emotions=self.track_bot_sentiment_config.emotions
+                emotions=self.sentiment_config.emotions
             )
         if self.agent.get_agent_config().end_conversation_on_goodbye:
             self.goodbye_model = GoodbyeModel()
@@ -127,13 +118,13 @@ class StreamingConversation:
             self.transcript.add_bot_message(
                 self.agent.get_agent_config().initial_message.text
             )
-        if self.synthesizer.get_synthesizer_config().track_bot_sentiment_in_voice:
+        if self.synthesizer.get_synthesizer_config().sentiment_config:
             self.update_bot_sentiment()
         self.send_message_to_stream_nonblocking(
             self.agent.get_agent_config().initial_message, False
         )
         self.active = True
-        if self.synthesizer.get_synthesizer_config().track_bot_sentiment_in_voice:
+        if self.synthesizer.get_synthesizer_config().sentiment_config:
             self.track_bot_sentiment_task = asyncio.create_task(
                 self.track_bot_sentiment()
             )
